//
//  ViewController.m
//  WanCmsSDK-Code
//
//  Created by Stack on 2017/2/10.
//  Copyright © 2017年 Joker_chen. All rights reserved.
//

#import "ViewController.h"
#import "YGGravityImageView.h"
#import "YGMessage.h"
#import <WanCmsSDK/WCmsSDK.h>
#define KeyWindowWidth [UIScreen mainScreen].bounds.size.width
#define KeyWindowHeight [UIScreen mainScreen].bounds.size.height

typedef NS_ENUM(int , ScreenFlag) {
    Horizontal = 0, //横屏
    Vertical,     //竖屏
};

@interface ViewController ()
@property (weak, nonatomic) IBOutlet UIButton *loginBtn;
@property (weak, nonatomic) IBOutlet UIButton *payBtn;
@property (weak, nonatomic) IBOutlet UIButton *roleBtn;
@property (weak, nonatomic) IBOutlet UIButton *closeBtn;
@property (weak, nonatomic) IBOutlet UIImageView *imageView;
@property (nonatomic, copy) NSString *userName;
@end

@implementation ViewController

- (void)viewWillAppear:(BOOL)animated{
    [super viewWillAppear:animated];
    self.navigationController.navigationBar.hidden = YES;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor clearColor];
    //切换账号回调
    [WCmsSDK sharedInstance].exitLogin = ^(NSDictionary *resultDic) {
        NSLog(@"%@切换账号回调",resultDic);
       };
}

- (void)showWarningMsg:(NSString *)msg{
    UIAlertController *alterVC = [UIAlertController alertControllerWithTitle:@"提示" message:msg preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *okAction = [UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
    }];
    [alterVC addAction:okAction];
    [self presentViewController:alterVC animated:YES completion:nil];
}

// 点击登录
- (IBAction)loginClick{
    if (_userName.length) {
        return;
    }
    __weak typeof(self) weakSelf = self;
    [[WCmsSDK sharedInstance] addLoginView:^(NSDictionary *resultDic) {
        NSLog(@"登录回调 = %@ 登录提示 = %@", resultDic,resultDic[@"msg"]);
        if ([resultDic[@"code"] intValue] == 1) {
            weakSelf.userName = resultDic[@"username"];
            [weakSelf.loginBtn setTitle:weakSelf.userName forState:UIControlStateNormal];
            weakSelf.loginBtn.titleLabel.font = [UIFont systemFontOfSize:18 weight:UIFontWeightRegular];
        }
    }];

}

// 点击支付
- (IBAction)payClick{
    
    // 加载支付界面
    if (!_userName.length) {
        [self showWarningMsg:@"请先登录"];
        return;
    }
    [self doPayAlter];
}

- (void)doPayAlter{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"设置金额" message:nil preferredStyle:UIAlertControllerStyleAlert];
    __weak typeof(alertController) weakAlert = alertController;
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"输入有效金额，单位元";
        textField.keyboardType = UIKeyboardTypeNumbersAndPunctuation;
        textField.textAlignment = NSTextAlignmentCenter;
    }];
    UIAlertAction *cancelAction = [UIAlertAction actionWithTitle:@"取消" style:UIAlertActionStyleDestructive handler:nil];
    [alertController addAction:cancelAction];
    UIAlertAction *loginAction = [UIAlertAction actionWithTitle:@"确认" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        [self.view endEditing:YES];
        NSString *money = [weakAlert.textFields.firstObject text];
        if(money.length == 0){
            money = @"0.01";
        }
        [self goToPayWithMoney:money];
    }];
    [alertController addAction:loginAction];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)goToPayWithMoney:(NSString *)money{
    [[WCmsSDK sharedInstance] addPayViewWithRoleId:@"test001"
                                              money:money
                                           serverId:@"888"
                                        productName:[NSString stringWithFormat:@"%@元宝", money]
                                        productDesc:@"元宝描述"
                                         cpOrderId:@"cpOrder889433455"
                                             attach:[self getOrderNumber]
                                         completion:^(NSDictionary *resultDic) {
        NSLog(@"支付回调 = %@", resultDic);
    }];
}


// 设置用户信息
- (IBAction)roleInfoClick{
    if (!_userName.length) {
        [self showWarningMsg:@"请先登录"];
        return;
    }
    [[WCmsSDK sharedInstance] setUserInfoDataWithRoleId:@"test001"
                                                roleName:@"测试员"
                                               roleLevel:@"1"
                                                  zoneId:@"888"
                                                zoneName:@"NO.1"
                                                  attach:@""
                                              completion:^(NSDictionary *resultDic) {
        if ([resultDic[@"code"] intValue] == 1) {
            [YGMessage showMessage:@"上传成功"];
        }
    }];
}
// 退出登录
- (IBAction)loginOutClick{
    if (!_userName.length) {
        [self showWarningMsg:@"请先登录"];
        return;
    }
    [[WCmsSDK sharedInstance] doLoginOut];
    self.userName = nil;
    [self.loginBtn setTitle:@"登录" forState:UIControlStateNormal];
    self.loginBtn.titleLabel.font = [UIFont systemFontOfSize:20 weight:UIFontWeightBold];
}

/** 根据时间获取唯一字段 */
- (NSString *)getOrderNumber{
    CGFloat time = [[NSDate date] timeIntervalSince1970];
    double intTime = time * 1000;
    NSInteger arc = (arc4random()+1000) %10000;
    NSString *orderNumber = [NSString stringWithFormat:@"%.f%ld",intTime,(long)arc];
    return orderNumber;
}

@end



