//
//  WanCmsSDK-Code
//
//  Created by Stack on 2022/4/12.
//  Copyright © 2022 Joker_chen. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef void(^CompletionBlock)(NSDictionary *resultDic);

@interface WCmsSDK : NSObject

/**
 *  创建单例服务
 *
 *  @return 返回单例对象
 */
+ (WCmsSDK *)sharedInstance;

/**
 *  退出回调（SDK内切换账号、doLoginOut接口回调）
 *  注意：方法需要先执行(参照demo)
 */
@property (nonatomic, copy,setter=setExitLogin:) CompletionBlock exitLogin;

/**
 *  初始化方法,在应用didFinishLaunchingWithOptions中调用(必接)
 */

- (BOOL)initApi:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

/**
 *  登录接口
 *  @param completion     登录结果回调Block
 *  回调数据说明：
 *      code = 1    代表登录成功；其他失败
 *      sign            加密字段（用于验签）
 *      loginTime  登录时间戳（用于验签）
 *      rzStatus     0未实名 1成年 2未成年
 *      msg            提示
 *      username   用户唯一标识
 */
- (void)addLoginView:(CompletionBlock)completion;


/**
 *  支付接口
 *  @param roleId                   角色id（必须）
 *  @param money                     支付金额（必须）保留两位小数
 *  @param serverId              服务器id（必须）
 *  @param productName        商品名称（必须）
 *  @param productDesc        商品说明（必须）
 *  @param attach                   扩展参数（必须）
 *  @param completion          回调Block
 *  回调数据说明：
 *      code = 1 : 支付成功 ，其他失败
 *      msg        : 提示
 *      money   :  金额
 *   注意：支付回调状态不一定准确，请以后台服务器通知为准
 *        参数都为字符串
 */
- (void)addPayViewWithRoleId:(NSString *)roleId
                       money:(NSString *)money
                    serverId:(NSString*)serverId
                 productName:(NSString *)productName
                 productDesc:(NSString *)productDesc
                   cpOrderId:(NSString *) cpOrderId
                      attach:(NSString *)attach
                  completion:(CompletionBlock)completion;


/**
 *  注销接口
 *  回调结果同 [[WCmsSDK sharedInstance] setExitLogin:] 方法 ，
 */
- (void)doLoginOut;

/**
 *  设置用户信息－－－支持改名（option）
 *
 *  @param roleId   角色id               必须
 *  @param roleName 角色名(支持改名)       必须
 *  @param roleLevel    角色等级              必须
 *  @param zoneId   角色所在区服唯一标示符  必须
 *  @param zoneName 角色所在区服名         必须
 *  @param completion  回调Block
 *  回调数据说明：
 *       code = 1 成功  code = -1 提交失败  code = -2 信息不全
 */
- (void)setUserInfoDataWithRoleId:(NSString *)roleId
                         roleName:(NSString *)roleName
                        roleLevel:(NSString *)roleLevel
                           zoneId:(NSString *)zoneId
                         zoneName:(NSString *)zoneName
                           attach:(NSString *)attach
                       completion:(CompletionBlock)completion;

/** 用于支付回调(必接) */
- (void)application:(UIApplication *)app openURL:(NSURL *)url options:(NSDictionary<NSString *, id> *)options;


- (void)hidePriView;
@end

